@@ -2,16 +2,18 @@ from __future__ import annotations
 
 import functools
 import logging
-from typing import Any, Callable, Optional
+from typing import Any, Callable
 
 from django.http import HttpRequest, HttpResponse
 
+from request_token.commands import log_token_use
+
 from .exceptions import ScopeError, TokenNotFoundError
 
 logger = logging.getLogger(__name__)
 
 
-def _get_request_arg(*args: Any) -> Optional[HttpRequest]:
+def _get_request_arg(*args: Any) -> HttpRequest | None:
     """Extract the arg that is an HttpRequest object."""
     for arg in args:
         if isinstance(arg, HttpRequest):
@@ -20,8 +22,8 @@ def _get_request_arg(*args: Any) -> Optional[HttpRequest]:
 
 
 def use_request_token(
-    view_func: Optional[Callable] = None,
-    scope: Optional[str] = None,
+    view_func: Callable | None = None,
+    scope: str | None = None,
     required: bool = False,
 ) -> Callable:
     """
@@ -72,16 +74,16 @@ def use_request_token(
         if token.scope == scope:
             token.validate_max_uses()
             token.authenticate(request)
-            response = view_func(*args, **kwargs)
+            response: HttpResponse = view_func(*args, **kwargs)
             # this will only log the request here if the view function
             # returns a valid HttpResponse object - if the view function
             # raises an error, **or this decorator raises an error**, it
             # will be handled in the middleware process_exception function,
-            token.log(request, response)
+            log_token_use(token, request, response.status_code)
             return response
 
         raise ScopeError(
-            "RequestToken scope mismatch: '%s' != '%s'" % (token.scope, scope)
+            "RequestToken scope mismatch: '{}' != '{}'".format(token.scope, scope)
         )
 
     return inner
